#ifndef TRIDIAGONALMATRIX_H
#define TRIDIAGONALMATRIX_H

#include <iostream>

class TridiagonalMatrix // tridiagonális mátrix típusa
{
public:
    enum Exceptions { WRONGSIZE, INDEXOUTOFRANGE, NULLREGION, DIFFERENTSIZE }; // kivételek

    TridiagonalMatrix(int s); // konstruktor
    TridiagonalMatrix(const TridiagonalMatrix& other); // másoló konstruktor
    ~TridiagonalMatrix(); // destruktor

    const TridiagonalMatrix& operator=(const TridiagonalMatrix& a); // értékadás operátor
    TridiagonalMatrix operator-() const; // negálás
    int operator()(int i, int j) const; // lekérdező operátor
    int& operator()(int i, int j); // beállító operátor

    int Size() const { return size; } // méret lekérdezése
    void Resize(int s); // átméretezés
    int GetValue(int i, int j) const; // lekérdezõ mûvelet
    void SetValue(int i, int j, int value); // beállító mûvelet

    // barát mûveletek megadása:
    friend TridiagonalMatrix operator+(const TridiagonalMatrix& a, const TridiagonalMatrix& b);
    friend TridiagonalMatrix operator-(const TridiagonalMatrix& a, const TridiagonalMatrix& b);
    friend bool operator==(const TridiagonalMatrix& a, const TridiagonalMatrix& b);

    friend std::istream& operator>>(std::istream& s, TridiagonalMatrix& a);
    friend std::ostream& operator<<(std::ostream& s, const TridiagonalMatrix& a);

private:
    int* values; // az értékeket dinamikusan létrehozott tömbben tároljuk
    int size; // a méretet is eltátoljuk
};

TridiagonalMatrix operator+ (const TridiagonalMatrix& a, const TridiagonalMatrix& b); // összeadás
TridiagonalMatrix operator- (const TridiagonalMatrix& a, const TridiagonalMatrix& b); // szorzás
bool operator==(const TridiagonalMatrix& a, const TridiagonalMatrix& b); // egyenlőségvizsgálat
std::istream& operator>>(std::istream& s, TridiagonalMatrix& a); // beolvasás
std::ostream& operator<<(std::ostream& s, const TridiagonalMatrix& a); // kiírás

#endif // TRIDIAGONALMATRIX_H
